@@ -8,11 +8,13 @@ import argparse
 import logging
 from collections.abc import Sequence
 
-from .base import LOG, Command
+from fclogr.cli.sync import Syncer
+
+from .base import LOG, Command, InvalidArgumentError
 from .dev_entries import DevEntries, DevSRPM
 
 
-def main(argv: Sequence[str] | None = None, **kwargs) -> None:
+def get_command(argv: Sequence[str] | None = None, **kwargs) -> Command:
     parser = argparse.ArgumentParser(
         description="fclogr is a tool for managing RPM changelogs and updates", **kwargs
     )
@@ -39,8 +41,23 @@ def main(argv: Sequence[str] | None = None, **kwargs) -> None:
         level = getattr(logging, log_level)
         LOG.setLevel(level)
 
-    command = COMMANDS[action](**args)
-    command.run()
+    return COMMANDS[action](**args)
 
 
-COMMANDS: dict[str, type[Command]] = {"dev-entries": DevEntries, "dev-srpm": DevSRPM}
+def main(argv: Sequence[str] | None = None) -> int | str:
+    try:
+        command = get_command(argv)
+    except InvalidArgumentError as err:
+        # sys.exit() in the console_script handles this
+        return str(err)
+    r = command.run()
+    for func in command.cleanup:
+        func()
+    return r
+
+
+COMMANDS: dict[str, type[Command]] = {
+    "sync": Syncer,
+    "dev-entries": DevEntries,
+    "dev-srpm": DevSRPM,
+}
