@@ -8,6 +8,7 @@ import abc
 import argparse
 import logging
 from collections.abc import Callable
+from typing import Any
 
 fmt = "{levelname}:{name}: {message}"
 logging.basicConfig(format=fmt, style="{")
@@ -21,6 +22,8 @@ class InvalidArgumentError(Exception):
 
 
 class Command(abc.ABC):
+    _cleanup: list[Callable[[], Any]]
+
     @classmethod
     @abc.abstractmethod
     def make_parser(
@@ -29,5 +32,11 @@ class Command(abc.ABC):
         ...
 
     @abc.abstractmethod
-    def run(self):
+    def run(self) -> int:
         ...
+
+    @property
+    def cleanup(self) -> list[Callable[[], Any]]:
+        if getattr(self, "_cleanup", None) is None:
+            self._cleanup = []
+        return self._cleanup
